@@ -24,15 +24,13 @@ MainWindowBase::MainWindowBase(QWidget* parent, Qt::WindowFlags f)
 * keyboard focus properly between Edit Alarm Dialog windows and MessageWindow
 * windows.
 */
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 void MainWindowBase::enterEvent(QEnterEvent* e)
-#else
-void MainWindowBase::enterEvent(QEvent* e)
-#endif
 {
     if (theApp()->needWindowFocusFix())
         QApplication::setActiveWindow(this);
     KXmlGuiWindow::enterEvent(e);
 }
 
+#include "moc_mainwindowbase.cpp"
+
 // vim: et sw=4:
