@@ -1,7 +1,7 @@
 /*
  *  messagedisplayhelper.cpp  -  helper class to display an alarm or error message
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -10,8 +10,10 @@
 #include "messagedisplayhelper_p.h"
 #include "messagedisplay.h"
 
+#include "audioplayer.h"
 #include "displaycalendar.h"
 #include "functions.h"
+#include "kalarm.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
 #include "resourcescalendar.h"
@@ -26,15 +28,13 @@
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
 
+#include <KAboutData>
 #include <KLocalizedString>
 #include <KConfig>
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
 #include <KNotification>
-#include <phonon/MediaObject>
-#include <phonon/AudioOutput>
-#include <phonon/VolumeFaderEffect>
 
 #include <QByteArray>
 #include <QLocale>
@@ -53,6 +53,8 @@ namespace
 {
 const char FDO_SCREENSAVER_SERVICE[] = "org.freedesktop.ScreenSaver";
 const char FDO_SCREENSAVER_PATH[]    = "/org/freedesktop/ScreenSaver";
+
+const uint32_t SOUND_ID = 1;   // ID for sounds (needed in order to cancel)
 }
 
 // Error message bit masks
@@ -65,11 +67,10 @@ enum
 QList<MessageDisplayHelper*>   MessageDisplayHelper::mInstanceList;
 QHash<EventId, unsigned>       MessageDisplayHelper::mErrorMessages;
 // There can only be one audio thread at a time: trying to play multiple
-// sound files simultaneously would result in a cacophony, and besides
-// that, Phonon currently crashes...
-QPointer<QThread>     MessageDisplayHelper::mAudioThread;
-QPointer<AudioPlayer> MessageDisplayHelper::mAudioPlayer;
-MessageDisplayHelper* MessageDisplayHelper::mAudioOwner = nullptr;
+// sound files simultaneously would result in a cacophony.
+QPointer<QThread>           MessageDisplayHelper::mAudioThread;
+QPointer<AudioPlayerThread> MessageDisplayHelper::mAudioPlayer;
+MessageDisplayHelper*       MessageDisplayHelper::mAudioOwner = nullptr;
 
 /******************************************************************************
 * Construct the message display handler for the specified alarm.
@@ -877,17 +878,17 @@ void MessageDisplayHelper::startAudio()
         // player as a worker to run in the thread created inside QThread.
         QThread* audioThread = new QThread(this);
         mAudioThread = audioThread;    // set the QPointer
-        AudioPlayer* audioPlayer = new AudioPlayer(mAudioFile, mVolume, mFadeVolume, mFadeSeconds, mAudioRepeatPause);
+        AudioPlayerThread* audioPlayer = new AudioPlayerThread(mAudioFile, mVolume, mFadeVolume, mFadeSeconds, mAudioRepeatPause);
         mAudioPlayer = audioPlayer;    // set the QPointer
         audioPlayer->moveToThread(audioThread);
-        connect(audioThread, &QThread::started, audioPlayer, &AudioPlayer::execute);
-        connect(audioPlayer, &AudioPlayer::destroyed, audioThread, &QThread::quit);
+        connect(audioThread, &QThread::started, audioPlayer, &AudioPlayerThread::execute);
+        connect(audioPlayer, &AudioPlayerThread::destroyed, audioThread, &QThread::quit);
         connect(audioThread, &QThread::finished, audioThread, &QThread::deleteLater);
         connect(audioThread, &QThread::destroyed, audioThread, []() { qCDebug(KALARM_LOG) << "MessageDisplayHelper: Audio thread deleted"; });
         connect(audioThread, &QThread::destroyed, this, [this]() { if (mAudioOwner == parent()) mAudioOwner = nullptr; });
 
         // Set up connections not in the thread-worker relationship.
-        connect(audioPlayer, &AudioPlayer::readyToPlay, this, &MessageDisplayHelper::playReady);
+        connect(audioPlayer, &AudioPlayerThread::readyToPlay, this, &MessageDisplayHelper::playReady);
         connect(audioThread, &QThread::finished, this, &MessageDisplayHelper::playFinished);
         if (mSilenceButton)
             connect(mSilenceButton, &QAbstractButton::clicked, this, &MessageDisplayHelper::stopAudioPlay);
@@ -976,10 +977,12 @@ void MessageDisplayHelper::playFinished()
         mParent->closeDisplay();
 }
 
+AudioPlayerThread*  AudioPlayerThread::mInstance = nullptr;   // enable double deletion prevention
+
 /******************************************************************************
 * Constructor for audio player.
 */
-AudioPlayer::AudioPlayer(const QString& audioFile, float volume, float fadeVolume, int fadeSeconds, int repeatPause)
+AudioPlayerThread::AudioPlayerThread(const QString& audioFile, float volume, float fadeVolume, int fadeSeconds, int repeatPause)
     : QObject()
     , mFile(audioFile)
     , mVolume(volume)
@@ -987,25 +990,20 @@ AudioPlayer::AudioPlayer(const QString& audioFile, float volume, float fadeVolum
     , mFadeSeconds(fadeSeconds)
     , mRepeatPause(repeatPause)
 {
+    mInstance = this;
+    // All audio objects must be created in execute() to ensure they belong to the thread.
 }
 
 /******************************************************************************
 * Destructor for audio player.
 * Note that this destructor may be executed in the parent thread.
 */
-AudioPlayer::~AudioPlayer()
+AudioPlayerThread::~AudioPlayerThread()
 {
-    qCDebug(KALARM_LOG) << "MessageDisplayHelper::~AudioPlayer";
+    qCDebug(KALARM_LOG) << "MessageDisplayHelper::~AudioPlayerThread";
     mMutex.lock();
-    mPath.disconnect();
-    if (mFader)
-    {
-        mPath.removeEffect(mFader);
-        delete mFader;
-        mFader = nullptr;
-    }
-    delete mAudioObject;
-    mAudioObject = nullptr;
+    mInstance = nullptr;    // enable slots to detect that their instance has been deleted
+    delete mPlayer;
     mMutex.unlock();
     // Notify after deleting mAudioPlayer, so that isAudioPlaying() will
     // return the correct value.
@@ -1015,55 +1013,27 @@ AudioPlayer::~AudioPlayer()
 /******************************************************************************
 * Kick off playing the audio file.
 */
-void AudioPlayer::execute()
+void AudioPlayerThread::execute()
 {
     mMutex.lock();
-    if (mAudioObject)
+    if (mPlayer)
     {
         mMutex.unlock();
         return;
     }
-    qCDebug(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::execute:" << QThread::currentThread() << mFile;
-    const QString audioFile = mFile;
+    qCDebug(KALARM_LOG) << "AudioPlayerThread::execute:" << QThread::currentThread() << mFile;
     const QUrl url = QUrl::fromUserInput(mFile);
     mFile = url.isLocalFile() ? url.toLocalFile() : url.toString();
-    Phonon::MediaSource source(url);
-    if (source.type() == Phonon::MediaSource::Invalid)
+    mPlayer = new AudioPlayer(AudioPlayer::Alarm, url, mVolume, mFadeVolume, mFadeSeconds, this);
+    if (mPlayer->status() == AudioPlayer::Error)
     {
-        mError = xi18nc("@info", "Cannot open audio file: <filename>%1</filename>", audioFile);
         mMutex.unlock();
-        qCCritical(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::execute: Open failure:" << audioFile;
         return;
     }
-    mAudioObject = new Phonon::MediaObject(this);
-    mAudioObject->setCurrentSource(source);
-    mAudioObject->setTransitionTime(100);   // workaround to prevent clipping of end of files in Xine backend
-    mAudioOutput = new Phonon::AudioOutput(Phonon::NotificationCategory, this);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
-    mPath = Phonon::createPath(mAudioObject, mAudioOutput);
-    if (mVolume >= 0  ||  mFadeVolume >= 0)
-    {
-        if (mVolume >= 0)
-            mAudioOutput->setVolume(mVolume);
-        if (mFadeVolume >= 0  &&  mFadeSeconds > 0)
-        {
-            mFader = new Phonon::VolumeFaderEffect(this);
-            if (!mFader->isValid())
-            {
-                // The current Phonon backend doesn't support fading.
-                qCWarning(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer: Current Phonon backend does not support fading";
-                delete mFader;
-                mFader = nullptr;
-            }
-            else
-            {
-                if (mVolume < 0)
-                    mVolume = mAudioOutput->volume();
-                mPath.insertEffect(mFader);
-            }
-        }
-    }
-    connect(mAudioObject, &Phonon::MediaObject::stateChanged, this, &AudioPlayer::playStateChanged, Qt::DirectConnection);
-    connect(mAudioObject, &Phonon::MediaObject::finished, this, &AudioPlayer::checkAudioPlay, Qt::DirectConnection);
+    connect(mPlayer, &AudioPlayer::downloaded, this, &AudioPlayerThread::checkAudioPlay);
+    connect(mPlayer, &AudioPlayer::finished, this, &AudioPlayerThread::playFinished);
+    connect(this, &AudioPlayerThread::stopPlay, mPlayer, &AudioPlayer::stop);
+
     mPlayedOnce = false;
     mPausing    = false;
     mMutex.unlock();
@@ -1077,10 +1047,10 @@ void AudioPlayer::execute()
 * If it is ready to play, start playing it (for the first time or repeated).
 * If play has not yet completed, wait a bit longer.
 */
-void AudioPlayer::checkAudioPlay()
+void AudioPlayerThread::checkAudioPlay()
 {
     mMutex.lock();
-    if (!mAudioObject)
+    if (mPlayer->status() != AudioPlayer::Ready)
     {
         mMutex.unlock();
         return;
@@ -1089,7 +1059,7 @@ void AudioPlayer::checkAudioPlay()
         mPausing = false;
     else
     {
-        // The file has loaded and is ready to play, or play has completed
+        // The file is ready to play, or play has completed
         if (mPlayedOnce)
         {
             if (mRepeatPause < 0)
@@ -1103,7 +1073,7 @@ void AudioPlayer::checkAudioPlay()
             {
                 // Pause before playing the file again
                 mPausing = true;
-                QTimer::singleShot(mRepeatPause * 1000, this, &AudioPlayer::checkAudioPlay);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
+                QTimer::singleShot(mRepeatPause * 1000, this, &AudioPlayerThread::checkAudioPlay);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
                 mMutex.unlock();
                 return;
             }
@@ -1112,89 +1082,54 @@ void AudioPlayer::checkAudioPlay()
     }
 
     // Start playing the file, either for the first time or again
-    qCDebug(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::checkAudioPlay: start";
-    if (mVolume >= 0)
-        mAudioOutput->setVolume(mVolume);
-    if (mFader)
-    {
-        mFader->setVolume(mFadeVolume);
-        mFader->fadeTo(mVolume, mFadeSeconds * 1000);
-    }
-    mAudioObject->play();
+    qCDebug(KALARM_LOG) << "AudioPlayerThread::checkAudioPlay: start";
+    mPlayer->play();
     mMutex.unlock();
 }
 
 /******************************************************************************
-* Called when the playback object changes state.
-* If an error has occurred, quit and return the error to the caller.
+* Called to notify play completion or cancellation.
 */
-void AudioPlayer::playStateChanged(Phonon::State newState)
+void AudioPlayerThread::playFinished(bool ok)
 {
-    qCDebug(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::playStateChanged:" << newState;
-    switch (newState)
+    if (ok)
     {
-        case Phonon::StoppedState:
-            mMutex.lock();
-            if (mStopping)
-            {
-                mPath.disconnect();
-                if (mFader)
-                {
-                    // Delete fader from the audio thread, in case it is still active.
-                    // because its timers can't be stopped from another thread.
-                    mPath.removeEffect(mFader);
-                    delete mFader;
-                    mFader = nullptr;
-                }
-                deleteLater();
-            }
-            mMutex.unlock();
-            break;
-
-        case Phonon::ErrorState:
-        {
-            QMutexLocker locker(&mMutex);
-            const QString err = mAudioObject->errorString();
-            if (!err.isEmpty())
-            {
-                qCCritical(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::playStateChanged: Play failure:" << mFile << ":" << err;
-                mError = xi18nc("@info", "<para>Error playing audio file: <filename>%1</filename></para><para>%2</para>", mFile, err);
-                exit(1);
-            }
-            break;
-        }
-
-        default:
-            break;
+        mMutex.lock();
+        if (mStopping)
+            deleteLater();
+        mMutex.unlock();
+        QTimer::singleShot(0, this, &AudioPlayerThread::checkAudioPlay);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
+    else
+        exit(1);
 }
 
 /******************************************************************************
 * Called when play completes, the Silence button is clicked, or the display is
 * closed, to terminate audio access.
 */
-void AudioPlayer::stop()
+void AudioPlayerThread::stop()
 {
-    qCDebug(KALARM_LOG) << "MessageDisplayHelper::AudioPlayer::stop";
+    qCDebug(KALARM_LOG) << "AudioPlayerThread::stop";
     mMutex.lock();
-    mStopping = true;
-    if (mAudioObject)
+    if (!mInstance)
     {
-        if (mAudioObject->state() != Phonon::StoppedState)
-        {
-            mAudioObject->stop();
-            mMutex.unlock();
-            return;
-        }
+        mMutex.unlock();
+        return;    // this instance has now been deleted
     }
+    mStopping = true;
+    // Calling AudioPlayer::stop() executes it in this thread, which causes crashes,
+    // so use signal-slot mechanism to call it in AudioPlayer's own thread.
+    Q_EMIT stopPlay();
     mMutex.unlock();
-    deleteLater();
+    if (mInstance)    // guard against this instance having already been deleted
+        deleteLater();
 }
 
-QString AudioPlayer::error() const
+QString AudioPlayerThread::error() const
 {
     QMutexLocker locker(&mMutex);
-    return mError;
+    return mPlayer->error();
 }
 
 /******************************************************************************
