@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -382,9 +382,14 @@ PrefsTabBase::PrefsTabBase(StackedScrollGroup* scrollGroup)
     QFrame* topWidget = new QFrame(this);
     setWidget(topWidget);
     mTopLayout = new QVBoxLayout(topWidget);
-    mTopLayout->setContentsMargins({});
+    mTopLayout->setContentsMargins(
+        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
 
-    if (!mIndentWidth) {
+    if (!mIndentWidth)
+    {
         QCheckBox cb(this);
         mIndentWidth = CheckBox::textIndent(&cb);
         mGridIndentWidth = mIndentWidth - style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
@@ -439,11 +444,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
 {
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Run Mode"));
     topLayout()->addWidget(group);
-    topLayout()->setContentsMargins(
-        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
-        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     auto vlayout = new QVBoxLayout(group);
 
     // Start at login
@@ -689,12 +689,6 @@ void MiscPrefTab::slotOtherTerminalToggled(bool on)
 TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
-    topLayout()->setContentsMargins(
-        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
-        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
-
     const int marLeft  = style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
     const int marRight = style()->pixelMetric(QStyle::PM_LayoutRightMargin);
     const int marTop   = style()->pixelMetric(QStyle::PM_LayoutTopMargin);
@@ -810,6 +804,7 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     QWidget* daybox = new QWidget(group);   // this is to control the QWhatsThis text display area
     layout->addWidget(daybox);
     auto wgrid = new QGridLayout(daybox);
+    wgrid->setContentsMargins(0, 0, 0, 0);
     const QLocale locale;
     for (int i = 0;  i < 7;  ++i)
     {
@@ -941,12 +936,6 @@ bool TimePrefTab::apply(bool syncToDisc)
 StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
-    topLayout()->setContentsMargins(
-        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
-        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
-
     // Which resource to save to
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "New Alarms && Templates"));
     topLayout()->addWidget(group);
@@ -1077,12 +1066,6 @@ void StorePrefTab::slotClearArchived()
 EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     : PrefsTabBase(scrollGroup)
 {
-    topLayout()->setContentsMargins(
-        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
-        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
-        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
-
     QWidget* widget = new QWidget;
     topLayout()->addWidget(widget);
     auto box = new QHBoxLayout(widget);
@@ -1357,10 +1340,14 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
 
     auto topTypes = new StackedGroupWidget(tabgroup);
     auto ttLayout = new QVBoxLayout(topTypes);
+    ttLayout->setContentsMargins(0, style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                 0, style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     mTabTypes = mTabs->addTab(topTypes, i18nc("@title:tab Settings specific to alarm type", "Type Specific"));
 
     auto topFontColour = new StackedGroupWidget(tabgroup);
     auto tfLayout = new QVBoxLayout(topFontColour);
+    tfLayout->setContentsMargins(0, style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                 0, style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     mTabFontColour = mTabs->addTab(topFontColour, i18nc("@title:tab", "Font && Color"));
 
     // MISCELLANEOUS
@@ -1802,10 +1789,14 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
 
     QWidget* widget = new QWidget;
     auto topGeneral = new QVBoxLayout(widget);
+    topGeneral->setContentsMargins(0, style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                   0, style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     mTabGeneral = mTabs->addTab(widget, i18nc("@title:tab", "General"));
 
     widget =  new QWidget;
     auto topWindows = new QVBoxLayout(widget);
+    topWindows->setContentsMargins(0, style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                   0, style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     mTabWindows = mTabs->addTab(widget, i18nc("@title:tab", "Alarm Windows"));
 
     // Run-in-system-tray check box or group.
@@ -1969,22 +1960,26 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     topWindows->addWidget(group);
     grid = new QGridLayout(group);
     grid->setColumnStretch(1, 1);
-    grid->setColumnMinimumWidth(0, gridIndentWidth());
-    mWindowPosition = new ButtonGroup(group);
-    connect(mWindowPosition, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotWindowPosChanged);
+    if (!KWindowSystem::isPlatformWayland())  // Wayland doesn't allow positioning of windows
+    {
+        grid->setColumnMinimumWidth(0, gridIndentWidth());
 
-    const QString whatsthis = xi18nc("@info:whatsthis",
-          "<para>Choose how to reduce the chance of alarm messages being accidentally acknowledged:"
-          "<list><item>Position alarm message windows as far as possible from the current mouse cursor location, or</item>"
-          "<item>Position alarm message windows in the center of the screen, but disable buttons for a short time after the window is displayed.</item></list></para>");
-    QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
-    mWindowPosition->addButton(radio, 0);
-    radio->setWhatsThis(whatsthis);
-    grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
-    radio = new QRadioButton(i18nc("@option:radio", "Center windows, delay activating window buttons"), group);
-    mWindowPosition->addButton(radio, 1);
-    radio->setWhatsThis(whatsthis);
-    grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
+        mWindowPosition = new ButtonGroup(group);
+        connect(mWindowPosition, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotWindowPosChanged);
+
+        const QString whatsthis = xi18nc("@info:whatsthis",
+              "<para>Choose how to reduce the chance of alarm messages being accidentally acknowledged:"
+              "<list><item>Position alarm message windows as far as possible from the current mouse cursor location, or</item>"
+              "<item>Position alarm message windows in the center of the screen, but disable buttons for a short time after the window is displayed.</item></list></para>");
+        QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "Position windows far from mouse cursor"), group);
+        mWindowPosition->addButton(radio, 0);
+        radio->setWhatsThis(whatsthis);
+        grid->addWidget(radio, 0, 0, 1, 2, Qt::AlignLeft);
+        radio = new QRadioButton(i18nc("@option:radio", "Center windows, delay activating window buttons"), group);
+        mWindowPosition->addButton(radio, 1);
+        radio->setWhatsThis(whatsthis);
+        grid->addWidget(radio, 1, 0, 1, 2, Qt::AlignLeft);
+    }
 
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     box = new QHBoxLayout(widget);
@@ -1995,6 +1990,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     mWindowButtonDelay->setRange(1, 10);
     mWindowButtonDelayLabel->setBuddy(mWindowButtonDelay);
     box->addWidget(mWindowButtonDelay);
+//TODO: Improve whatsthis text for Wayland
     widget->setWhatsThis(i18nc("@info:whatsthis",
                             "Enter how long its buttons should remain disabled after the alarm message window is shown."));
     box->addStretch();    // left adjust the controls
@@ -2059,7 +2055,8 @@ void ViewPrefTab::restore(bool, bool allTabs)
     }
     if (allTabs  ||  mTabs->currentIndex() == mTabWindows)
     {
-        mWindowPosition->setButton(Preferences::messageButtonDelay() ? 1 : 0);
+        if (mWindowPosition)
+            mWindowPosition->setButton(Preferences::messageButtonDelay() ? 1 : 0);
         mWindowButtonDelay->setValue(Preferences::messageButtonDelay());
         if (mModalMessages)
             mModalMessages->setChecked(Preferences::modalMessages());
@@ -2104,7 +2101,7 @@ bool ViewPrefTab::apply(bool syncToDisc)
         if (n != Preferences::autoHideSystemTray())
             Preferences::setAutoHideSystemTray(n);
     }
-    n = mWindowPosition->selectedId();
+    n = mWindowPosition ? mWindowPosition->selectedId() : 1;
     if (n)
         n = mWindowButtonDelay->value();
     if (n != Preferences::messageButtonDelay())
@@ -2184,10 +2181,12 @@ void ViewPrefTab::slotAutoHideSysTrayChanged(QAbstractButton* button)
 
 void ViewPrefTab::slotWindowPosChanged(QAbstractButton* button)
 {
-    const bool enable = mWindowPosition->id(button);
+    const bool enable = mWindowPosition ? mWindowPosition->id(button) : true;
     mWindowButtonDelay->setEnabled(enable);
     mWindowButtonDelayLabel->setEnabled(enable);
 }
+
 #include "moc_prefdlg_p.cpp"
 #include "moc_prefdlg.cpp"
+
 // vim: et sw=4:
